# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define name		spice
%define version		1.0
%define release		2jpp
%define	section		free


Name:		%{name}
Summary:	SPICE component repository
Url:		http://spice.codehaus.org/
Version:	%{version}
Release:	%{release}
Epoch:		0
License:	Open Source
Group:		Development/Libraries/Java
Vendor:		JPackage Project
Distribution:	JPackage
BuildArch:	noarch
Source0:	spice-1.0-src.tar.gz
##cvs -d :pserver:anonymous@cvs.spice.codehaus.org:/home/projects/spice/scm login
##cvs -z3 -d :pserver:anonymous@cvs.spice.codehaus.org:/home/projects/spice/scm co spice
Source1:        pom-maven2jpp-depcat.xsl
Source2:        pom-maven2jpp-newdepmap.xsl
Source3:        pom-maven2jpp-mapdeps.xsl
Source4:        spice-1.0-jpp-depmap.xml
Patch0:		spice-1.0-project.patch

BuildRequires:	maven
BuildRequires:	saxon, saxon-scripts
BuildRequires:	junit
BuildRequires:	avalon-framework
BuildRequires:	jakarta-commons-collections
BuildRequires:	jakarta-commons-jelly-tags-velocity
BuildRequires:	jakarta-commons-pool
BuildRequires:	isorelax
BuildRequires:	msv-strict
BuildRequires:	relaxngDatatype
BuildRequires:	velocity
BuildRequires:	xsdlib
Requires:	avalon-framework
Requires:	jakarta-commons-collections
Requires:	jakarta-commons-jelly-tags-velocity
Requires:	jakarta-commons-pool
Requires:	isorelax
Requires:	msv-strict
Requires:	relaxngDatatype
Requires:	velocity
Requires:	xsdlib
BuildRoot:	%{_tmppath}/%{name}-%{version}-buildroot

%description
Spice is a repository of Components which support 
Component Oriented Programming (COP) paradigms - 
in particular, the Inversion of Control (IoC) 
design pattern. 
Our aim is to developed components that are: 
highly reusable - leveraging on IoC 
deployable both in client and server containers 
well tested - with high unit test coverage 
The Components are designed to support deployment in 
different containers or frameworks. 
JContainer DNA is a framework supporting IoC. 
JContainer Loom is a container designed and implemented 
on top of the DNA framework, which also supports 
applications written in the Avalon framework. 
Pico Container supports IoC in a more agile and 
embeddable way, without the need to import any 
external interface or class. 
Plexus is a container designed and implemented on 
top of the DNA and Avalon Frameworks. 


%package javadoc
Summary:	Javadoc for %{name}
Group:		Development/Documentation

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{name}-%{version}
rm -rf sandbox
rm -rf components/alchemist
rm -rf components/loggerstore
rm -rf components/netserve
rm -rf components/threadpool
rm components/configkit/src/test/org/codehaus/spice/configkit/ConfigValidatorTestCase.java

%patch0 -p0

chmod -R go=u-w *
find . -name "*.jar" -exec rm -f {} \;
export DEPCAT=$(pwd)/spice-1.0-depcat.new.xml
echo '<?xml version="1.0" standalone="yes"?>' > $DEPCAT
echo '<depset>' >> $DEPCAT
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    /usr/bin/saxon project.xml %{SOURCE1} >> $DEPCAT
    popd
done
echo >> $DEPCAT
echo '</depset>' >> $DEPCAT
/usr/bin/saxon $DEPCAT %{SOURCE2} > spice-1.0-depmap.new.xml


%build
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp project.xml project.xml.orig
    /usr/bin/saxon -o project.xml project.xml.orig %{SOURCE3} map=%{SOURCE4}
    popd
done

for p in $(find . -name project.properties); do
    echo >> $p
    echo maven.repo.remote=file:/usr/share/maven-1.0/repository >> $p
    echo maven.home.local=$(pwd)/.maven >> $p
done
mkdir -p .maven/repository/JPP/jars


build-jar-repository -s -p .maven/repository/JPP/jars \
avalon-framework \
commons-collections \
commons-jelly-tags-velocity \
commons-pool \
isorelax \
junit \
msv-strict \
relaxngDatatype \
velocity \
xsdlib \

export MAVEN_HOME_LOCAL=$(pwd)/.maven
maven \
    -Dmaven.repo.remote=file:/usr/share/maven-1.0/repository \
    -Dmaven.home.local=${MAVEN_HOME_LOCAL} components:build
for c in configkit jndikit salt ; do
pushd components/$c
maven \
    -Dmaven.repo.remote=file:/usr/share/maven-1.0/repository \
    -Dmaven.home.local=${MAVEN_HOME_LOCAL} javadoc
popd
done

%install
# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}/%{name}
install -m 644 components/configkit/target/spice-configkit-1.3-dev.jar \
		$RPM_BUILD_ROOT%{_javadir}/%{name}/configkit-1.3-%{version}.jar
install -m 644 components/jndikit/target/spice-jndikit-1.1.jar \
		$RPM_BUILD_ROOT%{_javadir}/%{name}/jndikit-1.1-%{version}.jar
install -m 644 components/salt/target/spice-salt-1.1-dev.jar \
		$RPM_BUILD_ROOT%{_javadir}/%{name}/salt-1.1-%{version}.jar

pushd $RPM_BUILD_ROOT%{_javadir}/%{name} 
 for jar in *-%{version}*; do 
  ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; 
 done
 for jar in *-[0-9].[0-9].jar; do 
  ln -sf ${jar} `echo $jar| sed  "s|-[0-9]\.[0-9]||g"`; 
 done
popd

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
for c in configkit jndikit salt ; do
    install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/$c
    cp -pr components/$c/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/$c
done
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%files
%defattr(-,root,root)
%doc *.txt
%{_javadir}/%{name}

%files javadoc
%defattr(-,root,root)
%{_javadocdir}/%{name}-%{version}
%ghost %doc %{_javadocdir}/%{name}

%changelog
* Fri Mar 10 2006 Fernando Nasser <fnasser@redhat.com> 0:1.0-2jpp
- First JPP 1.7 build
- Adapt for maven 1.1 builds

* Mon Feb 21 2005 Ralph Apel <r.apel at r-apel.de> 0:1.0-1jpp
- First release with just a few of the components

